@@ -598,7 +598,7 @@ func (c *Container) WaitForExit(ctx context.Context, pollInterval time.Duration)
 		defer c.lock.Unlock()
 
 		if err := c.syncContainer(); err != nil {
-			if errors.Is(err, define.ErrNoSuchCtr) {
+			if errors.Is(err, define.ErrNoSuchCtr) || errors.Is(err, define.ErrCtrRemoved) {
 				// if the container is not valid at this point as it was deleted,
 				// check if the exit code was recorded in the db.
 				exitCode, err := c.runtime.state.GetContainerExitCode(id)
@@ -645,7 +645,7 @@ func (c *Container) WaitForExit(ctx context.Context, pollInterval time.Duration)
 
 	// we locked again so we must sync the state
 	if err := c.syncContainer(); err != nil {
-		if errors.Is(err, define.ErrNoSuchCtr) {
+		if errors.Is(err, define.ErrNoSuchCtr) || errors.Is(err, define.ErrCtrRemoved) {
 			// if the container is not valid at this point as it was deleted,
 			// check if the exit code was recorded in the db.
 			exitCode, err := c.runtime.state.GetContainerExitCode(id)
@@ -767,6 +767,12 @@ func (c *Container) WaitForConditionWithInterval(ctx context.Context, waitTimeou
 						// This allows callers to actually wait for the ctr to be removed.
 						if wantedStates[define.ContainerStateRemoving] &&
 							(errors.Is(err, define.ErrNoSuchCtr) || errors.Is(err, define.ErrCtrRemoved)) {
+							// check if the exit code was recorded in the db to return it
+							exitCode, err := c.runtime.state.GetContainerExitCode(c.ID())
+							if err == nil {
+								trySend(exitCode, nil)
+							}
+
 							trySend(-1, nil)
 							return
 						}
